NOID-mint Python Package

## Installation
```
pip install noid-mint
```
or
```
git clone git@github.com:VTUL/NOID.git
python setup.py install
```

## Usage
* Generate noid
```
noid -f local.yml
```

## Testing
```
nosetests
```
